@@ -4,22 +4,27 @@ Tests that the code can handle RC/FC evaluators that have both async and sync me
 
 import inject
 import pytest  # type:ignore[import]
-from maus.edifact import EdifactFormat, EdifactFormatVersion
 
 from ahbicht.content_evaluation.evaluationdatatypes import EvaluatableData, EvaluatableDataProvider, EvaluationContext
 from ahbicht.content_evaluation.fc_evaluators import FcEvaluator
 from ahbicht.content_evaluation.rc_evaluators import RcEvaluator
+from ahbicht.content_evaluation.token_logic_provider import SingletonTokenLogicProvider, TokenLogicProvider
 from ahbicht.expressions.ahb_expression_evaluation import evaluate_ahb_expression_tree
 from ahbicht.expressions.condition_nodes import ConditionFulfilledValue, EvaluatedFormatConstraint
 from ahbicht.expressions.expression_resolver import parse_expression_including_unresolved_subexpressions
-from ahbicht.expressions.hints_provider import DictBasedHintsProvider, HintsProvider
+from unittests.defaults import (
+    default_test_format,
+    default_test_version,
+    empty_default_hints_provider,
+    return_empty_dummy_evaluatable_data,
+)
 
 
 class MixedSyncAsyncRcEvaluator(RcEvaluator):
     """An RC evaluator that has both sync and async methods"""
 
-    edifact_format = EdifactFormat.UTILMD
-    edifact_format_version = EdifactFormatVersion.FV2104
+    edifact_format = default_test_format
+    edifact_format_version = default_test_version
 
     def _get_default_context(self):
         return None  # type:ignore[return-value]
@@ -40,8 +45,8 @@ class MixedSyncAsyncRcEvaluator(RcEvaluator):
 class MixedSyncAsyncFcEvaluator(FcEvaluator):
     """An FC Evaluator that has both sync and async methods"""
 
-    edifact_format = EdifactFormat.UTILMD
-    edifact_format_version = EdifactFormatVersion.FV2104
+    edifact_format = default_test_format
+    edifact_format_version = default_test_version
 
     def evaluate_901(self, _):
         return EvaluatedFormatConstraint(format_constraint_fulfilled=True, error_message=None)
@@ -63,16 +68,12 @@ class TestMixedSyncAsyncEvaluation:
         self, expression: str, expected_rc_fulfilled: bool, expected_fc_fulfilled: bool
     ):
         fc_evaluator = MixedSyncAsyncFcEvaluator()
-
-        def get_evaluatable_data():
-            return EvaluatableData(edifact_seed={})
-
         rc_evaluator = MixedSyncAsyncRcEvaluator()
         inject.clear_and_configure(
-            lambda binder: binder.bind(RcEvaluator, rc_evaluator)  # type:ignore[arg-type]
-            .bind(FcEvaluator, fc_evaluator)
-            .bind(HintsProvider, DictBasedHintsProvider({}))
-            .bind_to_provider(EvaluatableDataProvider, get_evaluatable_data)
+            lambda binder: binder.bind(  # type:ignore[arg-type]
+                TokenLogicProvider,
+                SingletonTokenLogicProvider([rc_evaluator, fc_evaluator, empty_default_hints_provider]),
+            ).bind_to_provider(EvaluatableDataProvider, return_empty_dummy_evaluatable_data)
         )
         evaluation_input = "something has to be here but it's not important what"
         tree = await parse_expression_including_unresolved_subexpressions(expression)
